/****************************************************************************************************/
/*																									*/
/*	Based on stm32_template by Paul Robson (paul@robsons.org.uk)													*/
/*				Simonsson Fun Techonlogies (original work on code for STM32)						*/
/*																									*/
/****************************************************************************************************/

/* STM32 includes */
#include <stm32f10x.h>
#ifdef USE_STDPERIPH_DRIVER
#include <stm32f10x_conf.h>
#endif

#include <inttypes.h>
#include "utils.h"

#include "lcd1202.h"


int main(void);
static void main_noreturn(void) __attribute__((noreturn));


static inline void sysInit(void)
{
    RCC->APB2ENR |=
        RCC_APB2ENR_IOPAEN |
        RCC_APB2ENR_IOPBEN |
        RCC_APB2ENR_IOPCEN |
        RCC_APB2ENR_IOPDEN |
        RCC_APB2ENR_USART1EN;

    GPIOA->BSRR = 0xFFFF;
    GPIOA->CRL = 0x88888888;
#ifdef USE_MCU_USART
    GPIOA->CRH = 0x888883BB;
#else
    GPIOA->CRH = 0x88888333;
#endif

    GPIOB->BSRR = 0xFFFF;
    GPIOB->CRL = 0x88888888;
    GPIOB->CRH = 0x88888888;

    GPIOC->BSRR = 0xFFFF;
    GPIOC->CRL = 0x88888888;
    GPIOC->CRH = 0x44838388;

    GPIOD->BSRR = 0xFFFF;
    GPIOD->CRL = 0x88888344;
    GPIOD->CRH = 0x88888888;

}

#define ledOn() GPIOC->BRR = (1<<12)
#define ledOff() GPIOC->BSRR = (1<<12)

/**
 * Main function
 */
int main(void)
{
    main_noreturn();
}

inline void main_noreturn(void)
{
    sysInit();
    lcd_init();

    lcd_str_center(lcdRows()-1, "(c) Ivan A-R");
    lcd_flags.inverse_char = -1;
    lcd_str(0, 0, " tuxotronic.org ");
    lcd_flags.inverse_char = 0;

    int cnt = 0;
    int i = 0;
    uint8_t okeys = 0xFF;
    while(1)
    {
        int n = cnt;
        uint8_t keys = (~GPIOC->IDR) & 0x1F;
        for(i=6; i>=0; i--)
        {
            ledOn();
            lcd_big_char(1, 2+i*13, (n % 10)+'0');
            ledOff();
            n /= 10;

            if(keys != okeys)
            {
                if(keys & (1<<i))
                    lcd_big_char(4, 2+i*13, i+'0');
                else
                    lcd_big_char(4, 2+i*13, '0'+14);
            }
        }
        okeys = keys;
        // lcd_start_line(cnt>>8);

        cnt++;
        if(cnt>9999999) cnt = 0;
    }
}

